summaryrefslogtreecommitdiff
path: root/include/llvm/Target/TargetLowering.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/llvm/Target/TargetLowering.h')
-rw-r--r--include/llvm/Target/TargetLowering.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/include/llvm/Target/TargetLowering.h b/include/llvm/Target/TargetLowering.h
index f257b035b8..bf1188ffdf 100644
--- a/include/llvm/Target/TargetLowering.h
+++ b/include/llvm/Target/TargetLowering.h
@@ -1287,14 +1287,14 @@ public:
return false;
}
/// getTypeForExtendedInteger - Return the type that should be used to zero or
/// sign extend a zeroext/signext integer argument or return value.
/// FIXME: Most C calling convention requires the return type to be promoted,
/// but this is not true all the time, e.g. i1 on x86-64. It is also not
/// necessary for non-C calling conventions. The frontend should handle this
/// and include all of the necessary information.
virtual MVT
- getTypeForExtendedInteger(EVT VT, ISD::NodeType ExtendKind) const {
+ getTypeForExtArgOrReturn(EVT VT, ISD::NodeType ExtendKind) const {
return MVT::i32;
}
@@ -1287,14 +1287,14 @@ public:
return false;
}
- /// getTypeForExtendedInteger - Return the type that should be used to zero or
+ /// getTypeForExtArgOrReturn - Return the type that should be used to zero or
/// sign extend a zeroext/signext integer argument or return value.
/// FIXME: Most C calling convention requires the return type to be promoted,